#
# spec file for package powdertoy
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Summary:        Physics sandbox game
License:        GPL-3.0
Group:          Amusements/Games/Other
Name:           powdertoy
Version:        92.5
Release:        lp151.2.4
Source:         https://github.com/simtr/The-Powder-Toy/archive/v%{version}.tar.gz
Patch0:         The-Powder-Toy-92.5-scons-3.patch
Url:            http://powdertoy.co.uk
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  ImageMagick
BuildRequires:  SDL-devel
BuildRequires:  SDL_mixer-devel
BuildRequires:  fftw3-devel
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  git
BuildRequires:  hicolor-icon-theme
BuildRequires:  libbz2-devel
BuildRequires:  lua51-devel
BuildRequires:  python-devel
BuildRequires:  scons
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel

%description
The Powder Toy is a free physics sandbox game, which simulates
air pressure and velocity, heat, gravity and a countless number
of interactions between different substances! The game provides
you with various building materials, liquids, gases and electronic
components which can be used to construct complex machines, guns,
bombs, realistic terrains and almost anything else.

%prep
%setup -q -n The-Powder-Toy-%{version}
%patch0 -p1

%build
%ifarch x86_64
scons --lin --release --64
%else
%ifarch %ix86
scons --lin --release --32
%else
scons --lin --release
%endif
%endif

%install
%ifarch %ix86
install -D -m 0755 build/powder %{buildroot}%{_bindir}/powder
%endif
%ifarch x86_64
install -D -m 0755 build/powder64 %{buildroot}%{_bindir}/powder
%endif
convert resources/powder.ico -strip resources/powder.png
install -D -m 0644 resources/powder-0.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/powder.png
install -D -m 0644 resources/powder-1.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/powder.png
install -D -m 0644 resources/powder-2.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/powder.png
install -D -m 0644 resources/powder-3.png %{buildroot}%{_datadir}/icons/hicolor/24x24/apps/powder.png
install -D -m 0644 resources/powder-4.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/powder.png

install -D -m 0644 resources/powder.desktop %{buildroot}%{_datadir}/applications/powder.desktop
install -D -m 0644 resources/powder.appdata.xml %{buildroot}%{_datadir}/appdata/powder.appdata.xml
install -D -m 0644 resources/powdertoy-save.xml %{buildroot}%{_datadir}/mime/packages/powdertoy-save.xml

%post
%icon_theme_cache_post
%desktop_database_post
%mime_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun
%mime_database_postun

%files
%defattr(-, root, root)
%doc README.md LICENSE TODO
%{_bindir}/powder
%{_datadir}/appdata/powder.appdata.xml
%{_datadir}/applications/powder.desktop
%{_datadir}/icons/hicolor/*/apps/powder.png
%{_datadir}/mime/packages/powdertoy-save.xml

%changelog
* Mon Nov 20 2017 astieger@suse.com
- fix build with scons 3, add The-Powder-Toy-92.5-scons-3.patch
* Wed Sep 27 2017 dsterba@suse.cz
- update to version 92.5
  * Added - New sim.takeSnapshot and tpt.record lua functions
  * Changed - Now compiled with luajit, should increase lua script performance by 10-40%%
  * Fix crash with BOMB explosions
* Mon Sep 11 2017 dsterba@suse.cz
- update to version 92.3.333
  * Added - New sim.takeSnapshot and tpt.record lua functions
  * Changed - Now compiled with luajit, should increase lua script performance by 10-40%%
  * Fix Mac (untested / unsupported) and Linux versions - luajit is now static
  * Fix crash with BOMB explosions
- update to version 92.2
  * Added: New sim.takeSnapshot and tpt.record lua functions
  * Now compiled with luajit, should increase lua script performance by 10-40%%
  * Fix crash with BOMB explosions
  * Fix illuminati symbols appearing when rescanning stamps
- update to version 92.1
  * Added: Hold shift when saving or loading stamps to not save / load pressure
  * Added: Android: ptsave links from the website now directly open the save in the app
  * Changed 'enter' closes SaveIDMessage interface after uploading a save
  * Turned off HSWC acts as insulator for HEAC
  * Fix -nan RFRG glitch
  * Fix newtonian gravity state transitions flashing
  * Fix issue where saving / loading saves could sometimes lag or crash the game
  * Ensure air doesn't "leak" out of TTAN containers when loading stamps and saves
  * Attempt to fix crash when zooming in on signs
  * Other minor fixes and changes
* Sat Aug  5 2017 rpm@fthiessen.de
- Update to version 92.0
  * New Element: POLO (polonium).
    Decays into NEUT rapidly unless cooled
  * New Element: HEAC (rapid heat conductor)
  * New Element: SAWD (sawdust). Floats on water
  * New Element: LSNS (life sensor)
  * New Element: RFRG (refrigerant).
    Heats up and liquifies under pressure
  * Add multiple undo and redo support (defaults to 5 undo states)
  * Add warning messages when certain words are found in comments
  * Add two new FILT modes, red/blue shift based only on ctype
  * Double the preciseness of photon refracting
  * CRMC now slightly scatters photons when reflecting
  * Pressure, air velocity, and ambient heat are now saved in saves
  * Proper ctrl+backspace support (doesn't delete entire textbox)
  * Add error message when attempting to login
    using an email address
  * Fix some piston bugs that could cause it to not push as far
    as it can
  * Fix PHOT/PLSM not following the correct heat scale in heat view
  * Fix issue with air sim that could cause massive lag after
    leaving TPT idle for 20 minutes
  * Fix floating point celcius in console: !set temp all 0.8C
  * Fix downvote button not being reset when opening a local save
  * Fix deco colors being 1 R/G/B value less than they should be
  * Fix favorites being able to be added multiple times
  * Fix issue where non-scrollable menus are stuck "scrolled"
  * Fix some issues with particle debugging
  * Fix crash with very high speed photons
  * Fix crash when PROT hits SPRK with no ctype
  * Fix potential crashes when loading
    or saving certain invalid saves
  * Fix crash when doing Textbox.new()
  * Fix high hexadecimal numbers working when setting type with
    PROP tool (can cause crashes)
  * Fix cache value from lua graphics function being ignored
- Dropped upstream merged patches: mime.patch, appdata.patch and
  desktop.patch
* Sun Feb  5 2017 mailaender@opensuse.org
- Add mime.patch for file type association
- Enhance appdata.patch with upstream changes
- Install documentation
* Sun Aug 21 2016 mailaender@opensuse.org
  * Update to version 91.5
  * Allow favoriting elements from the search UI
  * Hidden elements now show up in the favorites menu
  * Allow changing WHOL strengh with .tmp (like BHOL)
  * Minor fix to GEL<->SPNG water transfer
  * Fix invisible PIPE bug
  * Fix crash when using custom lua elements and the favorites menu at the same time
  * You can now undo stamp placement
  * Minor text fixes
  * Changes from version 91.4
  * New tool: MIX
  * Allow using C/F for temperature in PROP tool
  * Added a favorites menu
  * RPEL's ctype restricts the element it repels
  * Limit MERC to valid .tmp range
  * Force a stacking check when undoing
  * Don't reset edge mode when saving local saves
  * Allow hiding menusections via Lua
  * Allow mods to use the starcatcher build & update server
  * Fix gravity field re-appearing when undoing even if Newtonian Gravity is disabled
  * Fix LIFE tool sampling
  * Fix 'n' toggle also resetting air
  * Fix not being able to turn off FIND tool when a LIFE element is selected
  * Update .life properly when using particle debug shortcuts (tpt.setdebug(0x8))
  * Fix Crash when ctrl+opening a save
  * Fix blank screen when hitting "Cancel" on double screen prompt
  * Fixes to lua key events
* Mon May  2 2016 dsterba@suse.cz
- update to version 0.91.3.328
  - Version 91.3
  * Changed: 3D mode setting from 91.2 is still present in options (suggested
    value: -3)
  * Changed: Made 3D mode a little less laggy
  * Changed: THDR is no longer an energy particle
  * Fixed: Fixed 3D effect not working properly on OS X, fix yellow screens
    when turned off on OS X
  * Fixed: Some fixes to saving edge mode and double scale mode to
    powder.pref
  - Version 91.2
  * Added: The feature you've all been waiting for is here! 3-dimensional
    TPT!
  * Changed: Rewrite parts of the save browser to fix crashes on OS X /
    windows when opening saves
  * Changed: Remove virus ---- I mean, fix false virus detection with AVG
  * Changed: Note: It has been reported that the 3D doesn't work for some
    people, and instead TPT turns yellow. Since yellow is such a nice color,
    this is now a feature.
  - Version 91.1
  * Added: In game changelogs! (actually they were added in 91.0)
  * Added: Ability to enroll in beta updates on the site (fixed)
  * Changed: Loop edge mode now allows particles to have velocities greater
    than the size of the screen
  * Changed: Stickman now has terminal velocity in loop edge mode
  * Changed: Don't render AMTR as a gas
  * Fixed: Fix progress bar disappearing on hover in local save browser
  * Fixed: Fix PBCN(LIGH)
  * Fixed: Fix crash when opening saves on OS X
* Wed Mar  9 2016 mailaender@opensuse.org
- add desktop/icon update macros
- drop arm_ppc.patch in agreement with upstream:
  https://github.com/simtr/The-Powder-Toy/pull/288
* Tue Mar  8 2016 dsterba@suse.cz
- update to version 0.91.0.324
  * Fix fullscreen on OS X
  * Fix bugs creating multiple stickmen, fix stickmen spawning bugs
  * Fix FIRE, CO2, and SMKE passing through powder only wall
  * Fix FIRE not burning things inside of walls
  * Fix empty holes in stamp browser when deleting stamps
  * Fix stamp and save thumbnails occasionally getting mixed up
  * Fix many obscure crashes
  * Cut down the amazon rain forest
  * CRAY .tmp2 now sets creation offset, just like DRAY
  * Fix FRZZ/FRZW (didn't work as intended)
  * Speed improvements to several elements, including EMP, ETRD, and streamlines
  * Allow DRAY to copy energy particles
  * STOR automatically transfers to PRTI
  * CONV tmp value can now be used to set an element to be converted
  * Tons of other changes and fixes not listed here
  * Better icon and .desktop file on Linux
  * Mouse drawing is automatically canceled when moving in / out of the zoom window
  * Redo profile viewer a bit, and show more information
  * Default "Large screen" option to on if your screen is large enough
  * When you are not logged in, you can save local saves without holding ctrl
  * Disable Newtonian Gravity entirely inside grav wall zones
  * New loop edge mode
  * New ctrl+f shortcut to locate elements
  * Add textbox in save / stamp browsers to jump to any page
  * Ability to publish saves in the browser without resaving
  * Allow PSTN movement amount to be set by PSTN temperature
  * Signs have tooltips now, and have a longer 45 character max
  * New signs: {s:user:jacob1|my saves!} and {aheat}
  * New element: CRMC, melting point gets higher under pressure
  * New wall tool which can erase walls, particles, and signs
  * Deco flood fill, floods decoration based on pixel color
  * .tmp2 shows in the HUD for elements which use it, ambeint heat now shown when enabled
- refresh arm_ppc.patch
* Sun Jul 12 2015 dsterba@suse.com
- update to version 0.90.2.322
  * https://github.com/simtr/The-Powder-Toy/releases/tag/v90.0.318
  * https://github.com/simtr/The-Powder-Toy/releases/tag/v90.0.316
* Mon Apr 14 2014 dap.darkness@gmail.com
- Update to version 89.2.283, see:
  * https://github.com/simtr/The-Powder-Toy/releases/tag/v89.2.283
  * https://github.com/simtr/The-Powder-Toy/releases/tag/v89.2.281
  * https://github.com/simtr/The-Powder-Toy/releases/tag/v89.1.278
  * https://github.com/simtr/The-Powder-Toy/releases/tag/v89.0.274
  * https://github.com/simtr/The-Powder-Toy/releases/tag/v89.0.273
- Switched to download_files service and upstream tarball.
- Added arm_ppc.patch not to force build arch
  and to fix arm & ppc builds.
* Sat Aug 31 2013 mailaender@opensuse.org
- Update to version 88.1.272
* Sun Jan 13 2013 joop.boonen@boonen.org
- Added BuildRequires libbz2-devel as it's not automatically
  installed for openSUSE > 12.2
* Tue Jun 29 2010 prusnak@opensuse.org
- cleanup specfile
  Tue Jun 29 00:00:00 CEST 2010 - Ilya N. Chernykh
- initial OBS build
